@@ -6,7 +6,7 @@ use parent 'Locale::Maketext';
 use I18N::LangTags::Detect;
 use File::Spec;
 use Carp;
-our $VERSION = v0.22.2;
+our $VERSION = v0.23.0;
 
 # Allow unknown phrases to just pass-through.
 our %Lexicon = (
@@ -33,8 +33,8 @@ our %Lexicon = (
     'PGXN Blog' => 'PGXN Blog',
     'FAQ' => 'FAQ',
     'Frequently Asked Questions' => 'Frequently Asked Questions',
-    'Release It' => 'Release It',
-    'Release it on PGXN' => 'Release it on PGXN',
+    'Release on PGXN' => 'Release on PGXN',
+    'How to release extensions on PGXN' => 'How to release extensions on PGXN',
     code => 'code',
     design => 'design',
     logo => 'logo',
@@ -290,7 +290,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2010-2021 David E. Wheeler.
+Copyright (c) 2010-2024 David E. Wheeler.
 
 This module is free software; you can redistribute it and/or modify it under
 the L<PostgreSQL License|https://www.opensource.org/licenses/postgresql>.
